---
name: "ds9"
section: "1"
platform: "linux"
package: "saods9"
version: "8.6+repack-5"
release: "Debian 13 (Trixie)"
platforms: ["linux"]
url: "https://new.carta.tech/ds9"
---

# ds9(1)

image tool for astronomy

## NAME

ds9 - image tool for astronomy

## SYNOPSIS

**ds9** \[*options*\]\

## DESCRIPTION

**DS9** DS9 is the modern image tool used by astronomers for visualization of astronomical data.  It supports a plethora of command line options, which may be used in a script-like fashion.  An instance of the program is entirely controllable from the commandline with the XPA tools.

## OPTIONS

-

  - **-analysis**

  histogram save

  ds9 -region composite

  ds9 -region dissolve

  ds9 -region template foo.tpl

  ds9 -region template foo.tpl at 13:29:55.92 +47:12:48.02 fk5

  ds9 -region savetemplate foo.tpl

  ds9 -region group new

  ds9 -region group foo new

  ds9 -region group foo update

  ds9 -region group foo select

  ds9 -region group foo color red

  ds9 -region group foo copy

  ds9 -region group foo delete

  ds9 -region group foo cut

  ds9 -region group foo font 'times 14 bold'

  ds9 -region group foo move 100 100

  ds9 -region group foo movefront

  ds9 -region group foo moveback

  ds9 -region group foo property delete no

  ds9 -region copy

  ds9 -region cut

  ds9 -region paste wcs

  ds9 -region undo

  ds9 -region open

  ds9 -region close

  rreedd For RGB frames,  sets the current color channel to red.

  **Syntax**

  \-red

  **Example:**

  ds9 -rgb -red foo.fits

  rreessttoorree Restore DS9 to a previous state from a backup save set.

  **Syntax**

  \-restore \<filename\>

  **Example:**

  ds9 -restore ds9.bck

  rrggbb Create RGB frame and control RGB frame parameters.

  **Syntax**

  \-rgb \[\] \
    \[red\| green\| blue\] \
    \[channel \[red\| green\| blue\] \] \
    \[view \[red\| green\| blue\]  \[yes\| no\] \] \
    \[system \<coordsys\> \] \
    \[lock wcs\| crop\| slice\| bin\| scale\| scalelimits\| colorbar\| block\| smooth \[yes\| no\] \] \
    \[open\| close\]

  **Example:**

  ds9 -rgb # create new rgb frame

  ds9 -rgb red # set current channel to red

  ds9 -rgb channel red # set current channel to red

  ds9 -rgb view blue no # turn off blue channel

  ds9 -rgb system wcs # set rgb coordinate system

  ds9 -rgb lock wcs yes

  ds9 -rgb lock crop yes

  ds9 -rgb lock slice yes

  ds9 -rgb lock bin yes

  ds9 -rgb lock scale yes

  ds9 -rgb lock scalelimits yes

  ds9 -rgb lock colorbar yes

  ds9 -rgb lock block yes

  ds9 -rgb lock smooth yes

  ds9 -rgb open

  ds9 -rgb close

  rrggbbaarrrraayy Load raw data array cube into rgb frame.

  **Syntax**

  \-rgbarray \<filename\> \[\[xdim=\<x\> , ydim=\<y\> \| dim=\<dim\> \] ,  \[zdim=3\] , bitpix=\<b\> , skip=\<s\> , endian=\[little\| big\] \]

  **Example:**

  ds9 -rgbarray foo.arr\[dim=512, zdim=3, bitpix=-32, endian=little\]

  $cat foo.arr \|  ds9 -rgbarray -\[dim=512, zdim=3, bitpix=-32, endian=little\]  rrggbbccuubbee Load FITS rgbcube into rgb frame.

  **Syntax**

  \-rgbcube \<filename\>

  **Example:**

  ds9 -rgbcube foo.fits

  $cat foo.fits \|  ds9 -rgbcube - rrggbbiimmaaggee Load FITS rgbimage into rgb frame.

  **Syntax**

  \-rgbimage \<filename\>

  **Example:**

  ds9 -rgbimage foo.fits

  $cat foo.fits \|  ds9 -rgbimage - rroottaattee Controls the rotation angle (in degrees) of the current frame.\<

  **Syntax**

  \-rotate \[\<value\> \] \
    \[to \<value\> \] \
    \[open\| close\]

  **Example:**

  ds9 -rotate 45

  ds9 -rotate to 30

  ds9 -rotate open

  ds9 -rotate close

  ssaammpp Configure SAMP protocol.

  **Syntax**

  \-samp \[yes\| no\] \
    \| client \[yes\| no\] \] \
    \| hub \[yes\| no\] \] \
    \| web hub \[yes\| no\] \] \
    \| connect\| disconnect\] \
    \[broadcast \[image\| table\] \] \
    \[send \[image\| table\]  \<application\> \] \
    \[hub \[start\| stop\| info\] \]

  **Example:**

  ds9 -samp yes

  ds9 -samp connect

  ds9 -samp broadcast

  ds9 -samp broadcast table

  ds9 -samp send table

  ds9 -samp send table topcat

  ds9 -samp hub info

  ssaattuurraattiioonn For HLS and HSV frames,  sets the current color channel to saturation.

  **Syntax**

  \-saturation

  **Example:**

  ds9 -hsv -saturation foo.fits

  ssaavvee Save loaded image data of current frame as FITS.

  **Syntax**

  \-save\[fits\| rgbimage\| rgbcube\| mecube\| mosaic\| mosaicimage\]  \<filename\>  \[image\| table\| slice\]

  **Example:**

  ds9 -save foo.fits

  ds9 -save fits foo.fits image

  ds9 -save fits foo.fits table

  ds9 -save fits foo.fits slice

  ds9 -save rgbimage foo.fits

  ds9 -save rgbcube foo.fits

  ds9 -save mecube foo.fits

  ds9 -save mosaic foo.fits

  ds9 -save mosaicimage foo.fits

  ssaavveeiimmaaggee Create a snap shot of the current DS9 window and save in specified image format. If no format specified,  the file name extension is used to determine the output format. Optional parameters: jpeg quality int(1-100) and tiff compression method.

  **Syntax**

  \-saveimage\[fits\| eps\| gif\| tiff\| jpeg\| png\] \<filename\>  -saveimage \<filename\> .jpeg \[int(1-100)\]  -saveimage \<filename\> .tiff \[none\| jpeg\| packbits\| deflate\]

  **Example:**

  ds9 -saveimage ds9.tiff

  ds9 -saveimage jpeg ds9.jpeg 75

  ssccaallee Controls the limits and color scale distribution.

  **Syntax**

  \-scale \[linear\| log\| pow\| sqrt\| squared\| asinh\| sinh\| histequ\] \
    \[log exp \<value\> \] \
    \[datasec yes\| no\] \
    \[limits \<minvalue\>  \<maxvalue\> \] \
    \[mode minmax\| \<value\> \| zscale\| zmax\] \
    \[scope local\| global\] \
    \[match\] \
    \[match limits\] \
    \[lock \[yes\| no\] \] \
    \[lock limits \[yes\| no\] \] \
    \[open\| close\]

  **Example:**

  ds9 -scale linear

  ds9 -scale log exp 100

  ds9 -scale datasec yes

  ds9 -scale histequ

  ds9 -scale limits 1 100

  ds9 -scale mode zscale

  ds9 -scale mode 99.5

  ds9 -scale scope local

  ds9 -scale match

  ds9 -scale match limits

  ds9 -scale lock yes

  ds9 -scale lock limits yes

  ds9 -scale open

  ds9 -scale close

  sshhmm Load a shared memory segment into the current frame.

  **Syntax**

  \-shm \[\<key\>  \[\<filename\> \] \] \
    \[key \<id\>  \[\<filename\> \] \] \
    \[shmid \<id\>  \[\<filename\> \] \] \
    \[fits \[key\| shmid\]  \<id\>  \[\<filename\> \] \] \
    \[mosaicimage \[iraf\| wcs\| wcsa...wcsz\| wfpc2\]  \[key\| shmid\]  \<id\>  \[\<filename\> \] \] \
    \[mosaic \[iraf\| wcs\| wcsa...wcsz\]  \[key\| shmid\]  \<id\>  \[\<filename\> \] \] \
    \[rgbcube \[key\| shmid\]  \<id\>  \[\<filename\> \] \] \
    \[rgbimage \[key\| shmid\]  \<id\>  \[\<filename\> \] \] \
    \[rgbarray \[key\| shmid\]  \<id\>  \[xdim=\<x\> , ydim=\<y\> \| dim=\<dim\> , zdim=3\] , bitpix=\<b\> ,  \[skip=\<s\> \] \] \
    \[array \[key\| shmid\]  \<id\>  \[xdim=\<x\> , ydim=\<y\> \| dim=\<dim\> \] , bitpix=\<b\> ,  \[skip=\<s\> \] \]

  **Example:**

  ds9 -shm 102

  ds9 -shm key 102

  ds9 -shm shmid 102 foo

  ds9 -shm fits 100 foo

  ds9 -shm mosaicimage iraf key 100 foo

  ds9 -shm mosaicimage wcs key 100 foo

  ds9 -shm mosaicimage wcsa key 100 foo

  ds9 -shm mosaicimage wfpc2 key 100 foo

  ds9 -shm mosaic iraf key 100 foo

  ds9 -shm mosaic wcs key 100 foo

  ds9 -shm rgbcube key 100 foo

  ds9 -shm rgbimage key 100 foo

  ds9 -shm rgbarray shmid 102 \[dim=32, zdim=3, bitpix=-32\]

  ds9 -shm array shmid 102 \[dim=32, bitpix=-32\]

  ssiiaa Support for VO Simple Image Access protocol. The first command will create a new search. All other commands operated on the last search created,  unless indicated otherwise via current command.

  **Syntax**

  \-sia\[2mass\| akari\| astrowise\| cadc\| cxc\| hla\| mast\| sdss\| skyview\| tgssadr\] \
    \[cancel\] \
    \[clear\] \
    \[close\] \
    \[save \<filename\> \] \
    \[export rdb\| tsv \<filename\> \] \
    \[coordinate \<ra\>  \<dec\>  \<coordsys\> \] \
    \[crosshair\] \
    \[current \<ref\> \] \
    \[name \<object\> \] \
    \[print\] \
    \[retrieve\] \
    \[radius \<value\>  degrees\| arcmin\| arcsec\] \
    \[sky \<skyframe\> \] \
    \[skyformat \<skyformat\> \] \
    \[system \<coordsys\> \] \
    \[update\]

  **Example:**

  ds9 -sia 2mass

  ds9 -sia cancel

  ds9 -sia clear

  ds9 -sia close

  ds9 -sia coordinate 202.48 47.21 fk5

  ds9 -sia crosshair

  ds9 -sia current 2mass

  ds9 -sia export tsv bar.tsv

  ds9 -sia name m51

  ds9 -sia print

  ds9 -sia retrieve

  ds9 -sia save foo.xml

  ds9 -sia radius 1 degrees

  ds9 -sia sky fk5

  ds9 -sia skyformat degrees

  ds9 -sia system wcs

  ds9 -sia update

  ssiinnggllee Set display mode to single.

  **Syntax**

  \-single

  **Example:**

  ds9 -single

  sskkyyvviieeww Support for SkyView image server at HEASARC.

  **Syntax**

  \-skyview \[\] \
    \[\<object\> \] \
    \[name \<object\> \| clear\] \
    \[\<ra\>  \<dec\> \]  # in wcs fk5\
    \[size \<width\>  \<height\>  degrees\| arcmin\| arcsec\] \
    \[pixels \<width\>  \<height\> \] \
    \[save yes\| no\] \
    \[frame new\| current\] \
    \[update frame\| crosshair\] \
    \[survey \<survey\> \] \
    \[open\| close\]

  **Example:**

  ds9 -skyview

  ds9 -skyview m31

  ds9 -skyview name m31

  ds9 -skyview name clear

  ds9 -skyview 00:42:44.404 +41:16:08.78

  ds9 -skyview size 60 60 arcmin

  ds9 -skyview pixels 600 600

  ds9 -skyview save yes

  ds9 -skyview frame current

  ds9 -skyview update frame

  ds9 -skyview survey sdssi

  ds9 -skyview open

  ds9 -skyview close

  sslleeeepp Delays execution for specified number of seconds. Default is 1 second.

  **Syntax**

  \-sleep \[#\]

  **Example:**

  ds9 -sleep

  ds9 -sleep 2

  sslliiccee nnoosslliiccee Indicates next files loaded are to treated as slices of a cube. Can be disabled with noslice command.

  **Syntax**

  \-slice \<filename\>  -noslice

  **Example:**

  ds9 -slice \*.fits

  ds9 -noslice

  ssmmooootthh Smooth current image or set smooth parameters. Boxcar width =2\*radius+1 Tophat diameter =2\*radius+1 Gaussian diameter =2\*radius+1, mean=0 Elliptical Gaussian diameter =2\*radius+1, mean=0

  **Syntax**

  \-smooth \[\] \
    \[yes\| no\] \
    \[function boxcar\| tophat\| gaussian\| elliptic\] \
    \[radius \<value\> \] \
    \[radiusminor \<value\> \] \
    \[sigma \<value\> \] \
    \[sigmaminor \<value\> \] \
    \[angle \<value\> \] \
    \[match\] \
    \[lock \[yes\| no\] \] \
    \[open\| close\]

  **Example:**

  ds9 -smooth

  ds9 -smooth yes

  ds9 -smooth function tophat

  ds9 -smooth radius 4

  ds9 -smooth radiusminor 4

  ds9 -smooth sigma 2.0

  ds9 -smooth sigmaminor 2.0

  ds9 -smooth angle 45

  ds9 -smooth match

  ds9 -smooth lock yes

  ds9 -smooth open

  ds9 -smooth close

  ssqquuaarreedd Select squared scale function for the current frame.

  **Syntax**

  \-squared

  **Example:**

  ds9 -squared

  ssqqrrtt Select square soot scale function for the current frame.

  **Syntax**

  \-sqrt

  **Example:**

  ds9 -sqrt

  ssoouurrccee Source TCL code from a file.

  **Syntax**

  \-source \<filename\>

  **Example:**

  ds9 -source extensions.tcl

  ttccll Execute one TCL command. Note: this a different behavior from previous versions of DS9.

  **Syntax**

  \-tcl \<tcl command\>

  **Example:**

  ds9 -tcl 'puts "Hello,  World"'

  ttiiffff Load TIFF image into current frame.

  **Syntax**

  \-tiff \<filename\>

  **Example:**

  ds9 -tiff foo.tiff

  $cat foo.fits \|  ds9 -tiff - ttiillee Controls the tile display mode.

  **Syntax**

  \-tile \[\] \
    \[yes\| no\] \
    \[mode grid\| column\| row\] \
    \[grid\] \
    \[grid mode automatic\| manual\] \
    \[grid direction x\| y\] \
    \[grid layout \<col\>  \<row\> \] \
    \[grid gap \<pixels\> \] \
    \[row\] \
    \[column\]

  **Example:**

  ds9 -tile

  ds9 -tile yes

  ds9 -tile mode row

  ds9 -tile grid

  ds9 -tile grid mode manual

  ds9 -tile grid direction x

  ds9 -tile grid layout 5 5

  ds9 -tile grid gap 10

  ds9 -tile row

  ds9 -tile column

  ttiittllee Changes the display window title to the specified name.

  **Syntax**

  \-title name

  **Example:**

  ds9 -title Voyager

  uunniixx Set the IRAF unix socket name,  used by IRAF to communicate with DS9. The default is /tmp/.IMT%d,  so that the standard IRAF unix socket is defined.

  **Syntax**

  \-unix name

  **Example:**

  ds9 -unix "/tmp/.IMT%d"

  uunniixx\_\_oonnllyy Only use the IRAF unix socket name. This is the same as -fifo none -port 0.

  **Syntax**

  \-unix\_only

  **Example:**

  ds9 -unix\_only

  uuppddaattee Updates the current frame or region of frame. In the second form,  the first argument is the number of the fits HDU (starting with 1) and the remaining args are a bounding box in IMAGE coordinates. By default,  the screen is updated the next available idle cycle. However,  you may force an immediate update by specifying the NOW option.

  **Syntax**

  \-update \[\] \
    \[# x1 y1 x2 y2\] \
    \[now\] \
    \[now # x1 y1 x2 y2\]

  **Example:**

  ds9 -update

  ds9 -update 1 100 100 300 400

  ds9 -update now

  ds9 -update now 1 100 100 300 400

  uurrll Load FITS from URL into the current frame

  **Syntax**

  \-url \<url\>

  **Example:**

  ds9 -url http://foo.bar.edu/foo.fits

  vvaalluuee For HSV frames,  sets the current color channel to value.

  **Syntax**

  \-value

  **Example:**

  ds9 -hsv -value foo.fits

  vveerrssiioonn Returns the current version of DS9 and exits.

  **Syntax**

  \-version

  **Example:**

  ds9 -version

  vviieeww Controls the GUI.

  **Syntax**

  \-view \[layout horizontal\| vertical\| basic\| advanced\] \
    \[multi yes\| no\] \
    \[keyvalue \<string\> \] \
    \[info yes\| no\] \
    \[panner yes\| no\] \
    \[magnifier yes\| no\] \
    \[buttons yes\| no\] \
    \[icons yes\| no\] \
    \[colorbar yes\| no\] \
    \[graph horizontal\| vertical yes\| no\] \
    \[filename yes\| no\] \
    \[object yes\| no\] \
    \[keyword yes\| no\] \
    \[minmax yes\| no\] \
    \[lowhigh yes\| no\] \
    \[units yes\| no\] \
    \[image\| physical\| wcs\| wcsa...wcsz yes\| no\] \
    \[frame yes\| no\] \
    \[rgb red yes\| no\] \
    \[rgb green yes\| no\] \
    \[rgb blue yes\| no\] \
    \[hls hue yes\| no\] \
    \[hls lightness yes\| no\] \
    \[hls saturation yes\| no\] \
    \[hsv hue yes\| no\] \
    \[hsv saturation yes\| no\] \
    \[hsv value yes\| no\]

  **Example:**

  ds9 -view layout vertical

  ds9 -view multi yes

  ds9 -view keyvalue BITPIX

  ds9 -view info yes

  ds9 -view panner yes

  ds9 -view magnifier yes

  ds9 -view buttons yes

  ds9 -view icons yes

  ds9 -view colorbar yes

  ds9 -view graph horizontal yes

  ds9 -view filename yes

  ds9 -view object yes

  ds9 -view keyword yes

  ds9 -view minmax yes

  ds9 -view lowhigh yes

  ds9 -view wcsa yes

  ds9 -view frame yes

  ds9 -view rgb red yes

  vviissuuaall Force DS9 to use the specified color visual. This argument MUST be the first argument listed. Requires the visual be available.

  **Syntax**

  \-visual \[truecolor\| truecolor8\| truecolor16\| truecolor24\]

  **Example:**

  ds9 -visual truecolor24

  vvllaa Support for VLA Sky Survey.

  **Syntax**

  \-vla \[\] \
    \[\<object\> \] \
    \[name \<object\> \| clear\] \
    \[\<ra\>  \<dec\> \]  # in wcs fk5\
    \[size \<width\>  \<height\>  degrees\| arcmin\| arcsec\] \
    \[save yes\| no\] \
    \[frame new\| current\] \
    \[update frame\| crosshair\] \
    \[survey first\| stripe82\] \
    \[open\| close\]

  **Example:**

  ds9 -vla

  ds9 -vla m31

  ds9 -vla name m31

  ds9 -vla name clear

  ds9 -vla 00:42:44.404 +41:16:08.78

  ds9 -vla size 60 60 arcmin

  ds9 -vla save yes

  ds9 -vla frame current

  ds9 -vla update frame

  ds9 -vla survey stripe82

  ds9 -vla open

  ds9 -vla close

  vvllssss Support for NRAO VLSS Sky Survey.

  **Syntax**

  \-vlss \[\] \
    \[\<object\> \] \
    \[name \<object\> \| clear\] \
    \[\<ra\>  \<dec\> \]  # in wcs fk5\
    \[size \<width\>  \<height\>  degrees\| arcmin\| arcsec\] \
    \[save yes\| no\] \
    \[frame new\| current\] \
    \[update frame\| crosshair\] \
    \[open\| close\]

  **Example:**

  ds9 -vlss

  ds9 -vlss m31

  ds9 -vlss name m31

  ds9 -vlss name clear

  ds9 -vlss 00:42:44.404 +41:16:08.78

  ds9 -vlss size 60 60 arcmin

  ds9 -vlss save yes

  ds9 -vlss frame current

  ds9 -vlss update frame

  ds9 -vlss open

  ds9 -nvess close

  vvoo Invoke an connection to a Virtual Observatory site.

  **Syntax**

  \-vo \[method xpa\| mime\] \
    \[server \<url\> \] \
    \[internal yes\| no\] \
    \[delay #\] \
    \[\<url\> \] \
    \[connect \<url\> \] \
    \[disconnect \<url\> \] \
    \[open\| close\]

  **Example:**

  ds9 -vo method xpa

  ds9 -vo server "http://foo.bar.edu/list.txt"

  ds9 -vo internal yes

  ds9 -vo delay 15 # keep-alive delay

  ds9 -vo chandra-ed

  ds9 -vo connect chandra-ed

  ds9 -vo disconnect chandra-ed

  ds9 -vo open

  ds9 -vo close

  wwccss Controls the World Coordinate System for the current frame. If the wcs system,  skyframe,  or skyformat is modified,  the info panel,  compass,  grid,  and

  - **-mecube**

    \<filename\>

  **Example:**

  ds9 -mecube foo.fits

   $cat foo.fits \|  ds9 -mecube -\
    mmiinnmmaaxx\
    This is how DS9 determines the min and max data values from the\
    data. SCAN will scan all data.

  **Syntax**

   \-minmax \[scan\| sample\| datamin\| irafmin\] \
    \[mode scan\| sample\| datamin\| irafmin\] \
    \[interval #\] \
    \[rescan\]

  **Example:**

  ds9 -minmax scan

  ds9 -minmax mode scan

  ds9 -minmax interval 100

  ds9 -minmax rescan

   mmooddee\
    Select the current mode.

  **Syntax**

   \-mode\
    \[none\| region\| crosshair\| colorbar\| pan\| zoom\| rotate\| catalog\| examine\| 3d\]

  **Example:**

  ds9 -mode crosshair

   mmoossaaiicc\
    Load FITS mosaic segment into current frame.

  **Syntax**

   \-mosaic \[wcs\| wcsa...wcsz\| iraf\]  \<filename\>

  **Example:**

  ds9 -mosaic foo.fits

  ds9 -mosaic wcs foo.fits

   $cat foo.fits \|  ds9 -mosaic -\
    $cat foo.fits \|  ds9 -mosaic wcs -\
    mmoossaaiicciimmaaggee\
    Load FITS mosaic image into current frame.

  **Syntax**

   \-mosaicimage \[wcs\| wcsa...wcsz\| iraf\| wfpc2\]  \<filename\>

  **Example:**

  ds9 -mosaicimage foo.fits

  ds9 -mosaicimage wcs foo.fits

   $cat foo.fits \|  ds9 -mosaicimage\
    $cat foo.fits \|  ds9 -mosaiimage wcs\
    mmoovviiee\
    Create a movie from snap shots of the DS9 window. A slice movie\
    cycles though all slices of a cube. A frame movie cycles through all\
    active frames. A 3d movie cycles through specified viewing angles.\
    The default action is slice. Movie types are either MPEG or Animated\
    GIF,  with default MPEG. Optional parameters for 3d: number of frames, \
    azimuth from/to,  elevation from/to,  slice from/to,  oscillate/repeat\
    times.

  **Syntax**

   \-movie \[slice\| frame\]  \[mpeg\| gif \<delay\>  blink\| fade\]  \<filename\> \
    \-movie 3d \[mpeg\| gif \<delay\> \]  \<filename\>  \[number\| az from\| az to\| el\
    from\| el to\| slice from\| slice to\| zoom from\| zoom to\| oscillate\| repeat\
    \<#\> \]

  **Example:**

  ds9 -movie slice mpeg ds9.mpg

  ds9 -movie frame gif ds9.gif

  ds9 -movie frame gif 100 fade ds9.gif

  ds9 -movie 3d mpeg ds9.mpg number 10 az from -60 az to 60 oscillate

   1\
    mmssgg\
    Specify a directory of translation tables to be loaded.

  **Syntax**

   \-msg \<directory\>

  **Example:**

  ds9 -msg $HOME/msgs

   mmuullttiiffrraammee\
    Load FITS multiple extension file as multiple images.

  **Syntax**

  - **-multiframe**

    \<filename\>

  **Example:**

  ds9 -multiframe foo.fits

   $cat foo.fits \|  ds9 -multiframe -\
    nnaammeesseerrvveerr\
    Support Name Server functions. Coordinates are in fk5.

  **Syntax**

   \-nameserver \[\<object\> \] \
    \[name \<object\> \] \
    \[skyformat degrees\| sexagesimal\] \
    \[pan\] \
    \[crosshair\] \
    \[open\| close\]

  **Example:**

  ds9 -nameserver m31

  ds9 -nameserver name m31

  ds9 -nameserver server ned-sao

  ds9 -nameserver skyformat sexagesimal

  ds9 -nameserver pan

  ds9 -nameserver crosshair

  ds9 -nameserver open

  ds9 -nameserver close

   nnootteess\
    Display Notebook.

  **Syntax**

  - **-notes**

    \[\<string\> \] \
      \[append \<string\> \] \
      \[insert \<string\> \] \
      \[clear\] \
      \[load \<filename\> \] \
      \[save \<filename\> \] \
      \[open\| close\]

  **Example:**

  ds9 -notes 'Hello World'

  ds9 -notes append 'Hello World'

  ds9 -notes insert 'Hello World'

  ds9 -notes clear

  ds9 -notes load foo.txt

  ds9 -notes save foo.txt

  ds9 -notes open

  ds9 -notes close

   nnrrrrdd\
    Load an NRRD (Nearly Raw Raster Data) file.

  **Syntax**

   \-nrrd \<filename\>

  **Example:**

  ds9 -nrrd foo.nrrd

   $cat foo.nrrd \|  xpaset ds9 -nrrd-\
    nnvvssss\
    Support for NRAO VLA Sky Survey.

  **Syntax**

   \-nvss \[\] \
    \[\<object\> \] \
    \[name \<object\> \| clear\] \
    \[\<ra\>  \<dec\> \]  # in wcs fk5\
    \[size \<width\>  \<height\>  degrees\| arcmin\| arcsec\] \
    \[save yes\| no\] \
    \[frame new\| current\] \
    \[update frame\| crosshair\] \
    \[open\| close\]

  **Example:**

  ds9 -nvss

  ds9 -nvss m31

  ds9 -nvss name m31

  ds9 -nvss name clear

  ds9 -nvss 00:42:44.404 +41:16:08.78

  ds9 -nvss size 60 60 arcmin

  ds9 -nvss save yes

  ds9 -nvss frame current

  ds9 -nvss update frame

  ds9 -nvss open

  ds9 -nvess close

   oorriieenntt\
    Controls the orientation of the current frame.

  **Syntax**

   \-orient \[none\| x\| y\| xy\] \
    \[open\| close\]

  **Example:**

  ds9 -orient xy

  ds9 -orient open

  ds9 -orient close

   ppaaggeesseettuupp\
    Controls Page Setup options.

  **Syntax**

   \-pagesetup \[orient portrait\| landscape\] \
    \[scale \<numberic\> \] \
    \[size letter\| legal\| tabloid\| poster\| a4\]

  **Example:**

  ds9 -pagesetup orient portrait

  ds9 -pagesetup scale 50

  ds9 -pagesetup size poster

   ppaann\
    Controls the current image cursor location for the current frame.

  **Syntax**

   \-pan \[\<x\>  \<h\>  \<coordsys\>  \[\<skyframe\> \] \]  # relative\
    \[to \<x\>  \<h\>  \<coordsys\>  \[\<skyframe\> \] \]  # absolute\
    \[open\| close\]

  **Example:**

  ds9 -pan 200 200 image# pan relative

  ds9 -pan to 400 400 physical# pan to physical coords

  ds9 -pan to 13:29:55 47:11:50 wcs fk# pan to wcs coords

  ds9 -pan open

  ds9 -pan close

   ppiixxeellttaabbllee\
    Display/Hide the pixel table.

  **Syntax**

   \-pixeltable \[\] \
    \[yes\| open\] \
    \[no\| close\]

  **Example:**

  ds9 -pixeltable

  ds9 -pixeltable yes

  ds9 -pixeltable open

  ds9 -pixeltable close

   pplloott\
    Display and configure data plots. The last plot created is assumed.\
    Plot data is assumed to be a pair of coordinates,  with optional error

  - **-plot**

    \[line\| bar \[\<ref\> \] \] \
      \[line\| bar \[\<ref\> \]  \<title\>  \<xaxis label\>  \<yaxis label\> \
      xy\| xyex\| xyey\| xyexey\] \
      \# create new plot from data file\
      plot \[line\| bar \<filename\>  \[\<ref\> \]  xy\| xyex\| xyey\| xyexey\] \
      \[line\| bar \<filename\>  \[\<ref\> \]  \<title\>  \<xaxis label\>  \<yaxis label\> \
      xy\| xyex\| xyey\| xyexey\] \
      \# existing plot\
      plot \[gui\] \
      \[load \<filename\>  xy\| xyex\| xyey\| xyexey\] \
      \[save \<filename\> \] \
      \[current \<ref\> \] \
      \[layout grid\| row\| column\| strip\] \
      \[layout strip scale \<percent\> \] \
      \[add graph line\| bar\] \
      \[current graph \<graph\> \] \
      \[delete graph\] \
      \[current dataset \<dataset\> \] \
      \[delete dataset\] \
      \[duplicate\] \
      \[stats yes\| no\] \
      \[list yes\| no\] \
      \[backup \<filename\> \] \
      \[restore \<filename\> \] \
      \[pagesetup orient portrait\| landscape\] \
      \[pagesetup size letter\| legal\| tabloid\| poster\| a4\] \
      \[print\] \
      \[print destination printer\| file\] \
      \[print command \<command\> \] \
      \[print filename \<filename\> \] \
      \[print color rgb\| gray\] \
      \[close\] \
      \[mode pointer\| zoom\] \
      \# export\
      plot \[export \<filename\> \] \
      \[export eps\| gif\| tiff\| jpeg\| png \<filename\> \] \
      \[export jpeg \<filename\>  \[int(1-100)\] \] \
      \[export tiff \<filename\>  none\| jpeg\| packbits\| deflate\] \] \
      \# configure graph\
      plot \[axis x\| y grid yes\| no\] \
      \[axis x\| y log yes\| no\] \
      \[axis x\| y flip yes\| no\] \
      \[axis x\| y auto yes\| no\] \
      \[axis x\| y min \<value\> \] \
      \[axis x\| y max \<value\> \] \
      \[axis x\| y format \<string\> \] \
      \[background \<value\> \] \
      \[legend yes\| no\] \
      \[legend position right\| left\| top\| bottom\| plotarea\] \
      \[font title\| labels\| numbers font times\| helvetica\| courier\] \
      \[font title\| labels\| numbers size \<value\> \] \
      \[font title\| labels\| numbers weight normal\| bold\] \
      \[font title\| labels\| numbers slant roman\| italic\] \
      \[title \<string\> \] \
      \[title x\| y \<string\> \] \
      \# dataset\
      plot \[show yes\| no\] \
      \[name \<string\> \] \
      \# line dataset\
      plot \[line smooth step\| linear\| cubic\| quadratic\| catrom\] \
      \[line color \<value\> \] \
      \[line width \<value\> \] \
      \[line dash yes\| no\] \
      \[line fill yes\| no\] \
      \[line fill color \<value\> \] \
      \[line shape symbol\
      none\| circle\| square\| diamond\| plus\| splus\| scross\| triangle\| arrow\] \
      \[line shape size \<integer\> \] \
      \[line shape color \<value\> \] \
      \[line shape fill yes\| no\] \
      \# bar dataset\
      plot \[bar border color \<value\> \] \
      \[bar border width \<value\> \] \
      \[bar fill yes\| no\] \
      \[bar color \<value\> \] \
      \[bar width \<value\> \] \
      \# error bar\
      plot \[error yes\| no\] \
      \[error color \<value\> \] \
      \[error cap yes\| no\] \
      \[error width \<value\> \]

  **Example:**

   \# create new empty plot window

  ds9 -plot line

  ds9 -plot bar

   \# create new plot from data file

  ds9 -plot line xy.dat xy

  ds9 -plot line xy.dat 'The Title' 'X Axis' 'Y Axis' xy

   \# existing plot

  ds9 -plot gui

  ds9 -plot load xy.dat xy

  ds9 -plot save foo.dat

  ds9 -plot current foo

  ds9 -plot layout strip

  ds9 -plot layout strip scale 30

  ds9 -plot add graph bar

  ds9 -plot current graph 1

  ds9 -plot delete graph

  ds9 -plot current dataset 1

  ds9 -plot delete dataset

  ds9 -plot duplicate

  ds9 -plot stats yes

  ds9 -plot list yes

  ds9 -plot backup foo.bck

  ds9 -plot restore foo.bck

  ds9 -plot pagesetup orient portrait

  ds9 -plot pagesetup size letter

  ds9 -plot print

  ds9 -plot print destination file

  ds9 -plot print command lp

  ds9 -plot print filename foo.ps

  ds9 -plot print color rgb

  ds9 -plot close

  ds9 -plot mode pointer

   \# export plot

  ds9 -plot export tiff foo.tiff jpeg

  ds9 -plot export jpeg foo.jpeg 75

  ds9 -plot export png foo.png

   \# configure graph

  ds9 -plot axis x grid yes

  ds9 -plot axis x log yes

  ds9 -plot axis x flip yes

  ds9 -plot axis x auto no

  ds9 -plot axis x min 1

  ds9 -plot axis x max 100

  ds9 -plot axis x format '%f'

  ds9 -plot background white

  ds9 -plot legend yes

  ds9 -plot legend position left

  ds9 -plot font numbers font times

  ds9 -plot font numbers size 12

  ds9 -plot font numbers weight bold

  ds9 -plot font numbers slant italic

  ds9 -plot title 'This is a Title'

  ds9 -plot title x 'X Axis'

  ds9 -plot title y 'Y Axis'

  ds9 -plot title legend 'This is the Legend'

   \# configure current dataset

  ds9 -plot show yes

  ds9 -plot name 'My Data'

   \# line dataset

  ds9 -plot line smooth step

  ds9 -plot line color red

  ds9 -plot line width 2

  ds9 -plot line dash yes

  ds9 -plot line fill no

  ds9 -plot line fill color red

  ds9 -plot line shape symbol circle

  ds9 -plot line shape size 5

  ds9 -plot line shape color cyan

  ds9 -plot line shape fill no

   \# bar dataset

  ds9 -plot bar border color red

  ds9 -plot bar border width 2

  ds9 -plot bar fill no

  ds9 -plot bar color red

  ds9 -plot bar width 10

  ds9 -plot error yes

  ds9 -plot error color red

  ds9 -plot error cap yes

  ds9 -plot error width 2

  ppnngg Load PNG image into current frame.

  **Syntax**

  \-png \<filename\>

  **Example:**

  ds9 png foo.png

  $cat foo.png \|  ds9 -png - ppoorrtt Set the IRAF port number,  used by IRAF to communicate with DS9. The default is 5137,  the standard IRAF port used by ximtool.

  **Syntax**

  \-port number

  **Example:**

  ds9 -port 5137

  ppoorrtt\_\_oonnllyy iinneett\_\_oonnllyy Only use the IRAF port number. This is the same as -fifo none -unix none.

  **Syntax**

  \-port\_only

  **Example:**

  ds9 -port\_only

  ppooww Select power scale function for the current frame.

  **Syntax**

  \-pow

  **Example:**

  ds9 -pow

  pprreeffss Controls various preference settings.

  **Syntax**

  \-prefs \[open\] \
    \[save\] \
    \[clear\] \
    \[close\] \
    \[bg color yes\| no\] \
    \[bg color \<color\> \] \
    \[nan color \<color\> \] \
    \[precision \<linear\>  \<degree\>  \<hms\>  \<dms\>  \<len linear\>  \<len degree\>  \<len arcmin\>  \<len arcsec\>  \<angle\> \] \
    \[theme \<theme\> \] \
    \[threads \<numeric\> \] \
    \[irafalign yes\| no\]

  **Example:**

  ds9 -prefs open

  ds9 -prefs save

  ds9 -prefs clear

  ds9 -prefs close

  ds9 -prefs bg color no

  ds9 -prefs bg color red

  ds9 -prefs nan color blue

  ds9 -prefs precision 8 7 4 3 8 7 5 3 8

  ds9 -prefs theme radiance

  ds9 -prefs threads 8

  ds9 -prefs iraf yes

  pprreesseerrvvee Preserve the follow attributes while loading a new image.

  **Syntax**

  - **-preserve**

    \[pan yes\| no\] \
      \[regions yes\| no\]

  **Example:**

  ds9 -preserve pan yes

  ds9 -preserve regions yes

  ppsspprriinntt Invokes postscript printing. Please see \_p\_r\_i\_n\_t for further details. pprriinntt Controls printing. Use print option to set printing options.

  **Syntax**

  \-print \[destination printer\| file\] \
    \[command \<command\> \] \
    \[filename \<filename\> \] \
    \[color rgb\| cmyk\| gray\] \
    \[level 1\| 2\| 3\] \
    \[resolution72\| screen\| 96\| 144\| 150\| 225\| 300\| 600\| 1200\]

  **Example:**

  ds9 -print

  ds9 -print destination file

  ds9 -print command lp

  ds9 -print filename foo.ps

  ds9 -print color cmyk

  ds9 -print level 2

  ds9 -print resolution 96

  pprriissmm Invoke FITS analysis tool.

  **Syntax**

  \-prism\
    \[open\] \
    \[\<filename\> \] \
    \[load \<filename\> \] \
    \[import xml\| rdb\| tsv \<filename\> \] \
    \[export xml\| rdb\| tsv \<filename\> \] \
    \[clear\] \
    \[current \<ref\> \] \
    \[ext \<int\> \| \<extname\> \] \
    \[first\| next\| prev\| last\] \
    \[goto \<int\> \] \
    \[image\] \
    \[mode newplot\| newgraph\| overplot\] \
    \[histogram \<col\>  \<numbins\>  \[\<min\>  \<max\> \] \] \
    \[plot \<colx\>  \<coly\>  \[\<colerrx\> \]  \[\<colerry\> \]  xy\| xyex\| xyey\| xyexey\]

  **Example:**

  ds9 -prism

  ds9 -prism open

  ds9 -prism foo.fits

  ds9 -prism load bar.fits

  ds9 -prism import tsv bar.tsv

  ds9 -prism clear

  ds9 -prism current prism2

  ds9 -prism ext 2

  ds9 -prism ext STDEVT

  ds9 -prism first

  ds9 -prism next

  ds9 -prism goto 20345

  ds9 -prism image

  ds9 -prism mode newplot

  ds9 -prism histogram RAWX 40

  ds9 -prism histogram RAWX 40 0 100

  ds9 -prism plot RAWX RAWY xy

  ds9 -prism plot RAWX RAWY PHA xyex

  ds9 -prism plot RAWX RAWY PHA PHI xyexey

  rraaiissee Raise in the window stacking order.

  **Syntax**

  \-raise

  **Example:**

  ds9 -raise

  rreeggiioonn Controls regions in the current frame.

  **Syntax**

  \-region \[\<filename\> \] \
    \[load \[all\]  \<filename\> \] \
    \[save \[select\]  \<filename\> \] \
    \[list \[close\| select\] \] \
    \[epsilon \<integer\> \] \
    \[show yes\| no\] \
    \[showtext yes\| no\] \
    \[centroid\] \
    \[centroid auto yes\| no\] \
    \[centroid radius \<value\> \| iteration \<value\> \] \
    \[move front\| back\] \
    \[select all\| none\| all\| front\| back\] \
    \[delete \[select\] \] \
    \[delete load \<filename\> \] \
    \[format ds9\| xml\| ciao\| saotng\| saoimage\| pros\| xy\] \
    \[system image\| physical\| wcs\| wcsa...wcsz\] \
    \[sky fk4\| fk5\| icrs\| galactic\| ecliptic\] \
    \[skyformat degrees\| sexagesimal\] \
    \[strip yes\| no\] \
    \[shape \<shape\> \] \
    \[color \<color\> \] \
    \[fill yes\| no\] ;\
    \[width \<width\> \] \
    \[dash yes\| no\] \
    \[font times\| helvetica\| courier\] \
    \[fontsize \<value\> \] \
    \[fontweight normal\| bold\] \
    \[fontslant roman\| italic\] \
    \[fixed\| edit\| rotate\| delete yes\| no\] \
    \[include\| exclude\| source\| background\] \
    \[command \<marker command\> \] \
    \[analysis histogram\| panda\| plot2d\| plot3d\| radial\| stats \[open\| close\| save\] \] \
    \[composite\] \
    \[dissolve\] \
    \[template \<filename\> \] \
    \[template \<filename\>  at \<ra\>  \<dec\>  \<coordsys\>  \<skyframe\> \] \
    \[savetemplate \<filename\> \] \
    \[group new\] \
    \[group \<tag\>  new\] \
    \[group \<tag\>  update\] \
    \[group \<tag\>  select\] \
    \[group \<tag\>  color \<color\> \] \
    \[group \<tag\>  copy\] \
    \[group \<tag\>  delete\] \
    \[group \<tag\>  cut\] \
    \[group \<tag\>  font \<font\> \] \
    \[group \<tag\>  move \<int\>  \<int\> \] \
    \[group \<tag\>  movefront\] \
    \[group \<tag\>  moveback\] \
    \[group \<tag\>  property \<property\>  yes\| no\] \
    \[copy\] \
    \[cut\] \
    \[paste image\| physical\| wcs\| wcsa...wcsz\] \
    \[undo\] \
    \[open\| close\]

  **Example:**

  ds9 -region foo.reg

  ds9 -region -format ciao bar.reg # load as ciao format

  ds9 -region foo.fits # FITS region files do not need a format specification

  ds9 -region load foo.reg # load foo.reg into current frame

  ds9 -region load all foo.reg # load foo.reg into all frames

  ds9 -region load '\*.reg'# expand \*.reg and load into current frame

  ds9 -region load all '\*.reg' # expand \*.reg and load into all frames

  ds9 -region save foo.reg

  ds9 -region save select foo.reg

  ds9 -region list

  ds9 -region list select

  ds9 -region list close

  ds9 -region epsilon 5

  ds9 -region show yes

  ds9 -region showtext no

  ds9 -region centroid

  ds9 -region centroid auto yes

  ds9 -region centroid radius 10

  ds9 -region centroid iteration 20

  ds9 -region move back

  ds9 -region move front

  ds9 -region select all

  ds9 -region select none

  ds9 -region select invert

  ds9 -region select front

  ds9 -region select back

  ds9 -region delete

  ds9 -region delete select

  ds9 -region delete load foo.reg

  ds9 -region format ds9

  ds9 -region system wcs

  ds9 -region sky fk5

  ds9 -region skyformat degrees

  ds9 -region strip yes

  ds9 -region shape ellipse

  ds9 -region color red

  ds9 -region fill yes

  ds9 -region width 3

  ds9 -region dash yes

  ds9 -region font times

  ds9 -region fontsize 24

  ds9 -region fontweight bold

  ds9 -region fontslant italic

  ds9 -region edit yes

  ds9 -region include

  ds9 -region command "circle 100 100 20 # color=red"

  ds9 -region analysis stats $ds9 -region analysis stats close $ds9 -region

## FILES

The complete text of the DS9 manual may be found on Debian systems at /usr/share/doc/saods9/ref/.

## AUTHOR

DS9 is a product of the Smithsonian Astrophysical Observatory.

This manual page was generated from the DS9 HTML documentation by a script written by Justin Pryzby and Ole Streicher.

## SEE ALSO

[*xpaget*(1)](/xpaget/1.md), [*xpaset*(1)](/xpaset/1.md), [*xpaaccess*(1)](/xpaaccess/1.md), [*xpamb*(1)](/xpamb/1.md), [*xpainfo*(1)](/xpainfo/1.md), [*xpans*(1)](/xpans/1.md), [*xpachanges*(7)](/xpachanges/7.md),
